Struct XdgWmBase
pub struct XdgWmBase { /* private fields */ }wayland and Linux only.Expand description
create desktop-style surfaces
The xdg_wm_base interface is exposed as a global object enabling clients to turn their wl_surfaces into windows in a desktop environment. It defines the basic functionality needed for clients and the compositor to create windows that can be dragged, resized, maximized, etc, as well as creating transient windows such as popup menus.
See also the Request enum for this interface.
Implementations
impl XdgWmBase
impl XdgWmBase
pub fn ping(&self, serial: u32)
pub fn ping(&self, serial: u32)
check if the client is alive
The ping event asks the client if it’s still alive. Pass the serial specified in the event back to the compositor by sending a “pong” request back with the specified serial. See xdg_wm_base.pong.
Compositors can use this to determine if the client is still alive. It’s unspecified what will happen if the client doesn’t respond to the ping request, or in what timeframe. Clients should try to respond in a reasonable amount of time. The “unresponsive” error is provided for compositors that wish to disconnect unresponsive clients.
A compositor is free to ping in any way it wants, but a client must always respond to any xdg_wm_base object it created.